@@ -18,7 +18,7 @@ a Qt-based screencast recorder
 all
 </installable>
 
-<screenshot>https://screenshots.debian.net/screenshots/000/015/303/large.png</screenshot>
+<screenshot>none</screenshot>
 
 <preinstall>
 
